require 'spec_helper'

describe 'puppet_enterprise::console::database' do
  before :each do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'console.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
    }

    @params = {
      'database_name' => 'console-db',
      'database_user' => 'console-user',
      'database_password' => 'secretpassword',
      'database_host' => 'database.rspec',
      'database_port' => 2345,
    }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }

  describe "managing dashboard database config" do
    let(:file) { '/etc/puppetlabs/puppet-dashboard/database.yml' }
    it { should contain_file(file).with(:owner => 'puppet-dashboard',
                                        :group => 'puppet-dashboard',
                                        :mode => '0640') }

    it { should have_yaml_file(file, 'production' => { 'database' => 'console-db',
                                                       'username' => 'console-user',
                                                       'password' => 'secretpassword',
                                                       'host' => 'database.rspec',
                                                       'port' => 2345,
                                                       'adapter' => 'postgresql' }) }
  end

  describe "migrating databases" do
    it { should contain_exec('migrate console database').with_command('rake db:migrate').that_requires('File[/etc/puppetlabs/puppet-dashboard/database.yml]') }
  end
end

