require 'spec_helper'

describe 'puppet_enterprise::profile::console::certs' do
  before :all do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'console.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
    }

    @params = { 'certname' => 'console-rspec' }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:dashboard_sharedir) { '/opt/puppet/share/puppet-dashboard' }
  let(:services_sharedir) { '/opt/puppet/share/console-services' }
  let(:ssldir) { '/etc/puppetlabs/puppet/ssl' }

  context "managing certs" do
    it { should contain_file("#{dashboard_sharedir}/certs").with_mode('0600') }
    it { should contain_file("#{services_sharedir}/certs").with_mode('0600') }
    it { should contain_file("#{dashboard_sharedir}/certs/pe-internal-dashboard.cert.pem").with(:source => "#{ssldir}/certs/pe-internal-dashboard.pem", :mode => '0400') }
    it { should contain_file("#{dashboard_sharedir}/certs/pe-internal-dashboard.private_key.pem").with(:source => "#{ssldir}/private_keys/pe-internal-dashboard.pem", :mode => '0400') }
    it { should contain_file("#{dashboard_sharedir}/certs/console-rspec.cert.pem").with(:source => "#{ssldir}/certs/console-rspec.pem", :mode => '0400') }
    it { should contain_file("#{dashboard_sharedir}/certs/console-rspec.private_key.pem").with(:source => "#{ssldir}/private_keys/console-rspec.pem", :mode => '0400') }
    it { should contain_file("#{services_sharedir}/certs/console-rspec.cert.pem").with(:source => "#{ssldir}/certs/console-rspec.pem", :mode => '0400') }
    it { should contain_file("#{services_sharedir}/certs/console-rspec.private_key.pem").with(:source => "#{ssldir}/private_keys/console-rspec.pem", :mode => '0400') }
    it { should contain_file("#{services_sharedir}/certs/pe-internal-classifier.cert.pem").with(:source => "#{ssldir}/certs/pe-internal-classifier.pem", :mode => '0400') }
    it { should contain_file("#{services_sharedir}/certs/pe-internal-classifier.private_key.pem").with(:source => "#{ssldir}/private_keys/pe-internal-classifier.pem", :mode => '0400') }
  end

end
